summaryrefslogtreecommitdiff
path: root/dbaccess/source/ui/inc/JoinController.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-08-03 09:14:58 +0200
committerNoel Grandin <noel@peralex.com>2015-08-03 13:38:44 +0200
commit7dc5e8731fdc3a11ca429e717ec4a05e67ea1d21 (patch)
tree104e82c3fdda21d4b33c4f427cee9023377b731f /dbaccess/source/ui/inc/JoinController.hxx
parent5edd744d1021b41f59528a6e3a8adebfe63e6b6e (diff)
com::sun::star->css in dbaccess
Change-Id: I4fbdd3fb7d1e0ad4423148aaaed3a15aebb26d14
Diffstat (limited to 'dbaccess/source/ui/inc/JoinController.hxx')
-rw-r--r--dbaccess/source/ui/inc/JoinController.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/dbaccess/source/ui/inc/JoinController.hxx b/dbaccess/source/ui/inc/JoinController.hxx
index 180b139769d9..1ccdd560618a 100644
--- a/dbaccess/source/ui/inc/JoinController.hxx
+++ b/dbaccess/source/ui/inc/JoinController.hxx
@@ -55,10 +55,10 @@ namespace dbaui
::std::unique_ptr< AddTableDialogContext > m_pDialogContext;
Point m_aMinimumTableViewSize;
// state of a feature. 'feature' may be the handle of a ::com::sun::star::util::URL somebody requested a dispatch interface for OR a toolbar slot.
virtual FeatureState GetState(sal_uInt16 nId) const SAL_OVERRIDE;
// execute a feature
- virtual void Execute(sal_uInt16 nId, const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue>& aArgs) SAL_OVERRIDE;
+ virtual void Execute(sal_uInt16 nId, const css::uno::Sequence< css::beans::PropertyValue>& aArgs) SAL_OVERRIDE;
/** loads the information for the windows.
@param i_rViewSettings
@@ -80,7 +80,7 @@ namespace dbaui
virtual ~OJoinController();
public:
- OJoinController(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& _rM);
+ OJoinController(const css::uno::Reference< css::uno::XComponentContext >& _rM);
// attribute access
inline TTableWindowData& getTableWindowData() { return m_vTableData; }
@@ -117,12 +117,12 @@ namespace dbaui
// UNO interface overridables
// XEventListener
- virtual void SAL_CALL disposing( const ::com::sun::star::lang::EventObject& Source ) throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual void SAL_CALL disposing( const css::lang::EventObject& Source ) throw(css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- // ::com::sun::star::lang::XComponent
+ // css::lang::XComponent
virtual void SAL_CALL disposing() SAL_OVERRIDE;
- // ::com::sun::star::frame::XController
- virtual sal_Bool SAL_CALL suspend(sal_Bool bSuspend) throw( ::com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+ // css::frame::XController
+ virtual sal_Bool SAL_CALL suspend(sal_Bool bSuspend) throw( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
// misc
/** only defines a method to save a SQLException in d&d methods to show the error at a later state
@@ -55,10 +55,10 @@ namespace dbaui
::std::unique_ptr< AddTableDialogContext > m_pDialogContext;
Point m_aMinimumTableViewSize;
- // state of a feature. 'feature' may be the handle of a ::com::sun::star::util::URL somebody requested a dispatch interface for OR a toolbar slot.
+ // state of a feature. 'feature' may be the handle of a css::util::URL somebody requested a dispatch interface for OR a toolbar slot.
virtual FeatureState GetState(sal_uInt16 nId) const SAL_OVERRIDE;
// execute a feature